/// <reference types="node" />
import { Application, BeneficialOwner, BeneficialOwnerDTO, ApplicationDocument, CreateApplicationRequest, DownloadDocumentRequest, PatchApplicationRequest, UploadDocumentRequest, VerifyDocumentRequest, CancelApplicationRequest, PatchBusinessApplicationBeneficialOwner, ApplicationStatus } from "../types/application";
import { UnitResponse, Include, UnitConfig, BaseListParams, Tags, Sort } from "../types/common";
import { BaseResource } from "./baseResource";
export declare class Applications extends BaseResource {
    private basePath;
    constructor(token: string, basePath: string, config?: UnitConfig);
    list(params?: ApplicationListParams): Promise<UnitResponse<Application[]>>;
    create(request: CreateApplicationRequest): Promise<UnitResponse<Application> & Include<ApplicationDocument[] | BeneficialOwner[]>>;
    upload(request: UploadDocumentRequest): Promise<UnitResponse<ApplicationDocument>>;
    update(request: PatchApplicationRequest): Promise<UnitResponse<Application>>;
    get(applicationId: string): Promise<UnitResponse<Application> & Include<ApplicationDocument[]>>;
    listDocuments(applicationId: string): Promise<UnitResponse<ApplicationDocument[]>>;
    createDocument(applicationId: string): Promise<UnitResponse<ApplicationDocument>>;
    verifyDocument(request: VerifyDocumentRequest): Promise<UnitResponse<ApplicationDocument>>;
    cancel(request: CancelApplicationRequest): Promise<UnitResponse<Application> & Include<ApplicationDocument[]>>;
    download(request: DownloadDocumentRequest): Promise<Buffer>;
    updateBeneficialOwner(request: PatchBusinessApplicationBeneficialOwner): Promise<UnitResponse<BeneficialOwnerDTO>>;
}
export interface ApplicationListParams extends BaseListParams {
    /**
     * Optional. Search term according to the Full-Text Search Rules.
     * default: empty
     */
    query?: string;
    /**
     * Optional. Filter applications by email address (case sensitive).
     * default: empty
     */
    email?: string;
    /**
     * Optional. Filter Applications by Tags.
     * default: empty
     */
    tags?: Tags;
    /**
     * Optional. sort=createdAt for ascending order or sort=-createdAt (leading minus sign) for descending order.
     * default: sort=-createdAt
     */
    sort?: Sort;
    /**
     * Optional. Filter applications by [Application Status](https://docs.unit.co/applications#application-statuses). Usage example: filter[status][0]=Pending&filter[status][1]=Approved
     */
    status?: ApplicationStatus[];
}
